==> clarity-demos-0.6.3.tgz: package/dropdown/demo/dropdown.demo.routing.js <==
"use strict";
var router_1 = require("@angular/router");
var dropdown_demo_1 = require("./dropdown.demo");
var dropdown_static_default_1 = require("./dropdown-static-default");
var dropdown_static_positioning_1 = require("./dropdown-static-positioning");
var dropdown_static_fontawesome_toggle_1 = require("./dropdown-static-fontawesome-toggle");
var dropdown_static_icon_toggle_1 = require("./dropdown-static-icon-toggle");
var dropdown_static_textlink_toggle_1 = require("./dropdown-static-textlink-toggle");
var dropdown_angular_positioning_1 = require("./dropdown-angular-positioning");
var dropdown_angular_close_item_false_1 = require("./dropdown-angular-close-item-false");
var ROUTES = [
    {
        path: "",
        component: dropdown_demo_1.DropdownDemo,
        children: [
            { path: "", redirectTo: "default", pathMatch: "full" },
            { path: "default", component: dropdown_static_default_1.DropdownStaticDefaultDemo },
            { path: "positioning", component: dropdown_static_positioning_1.DropdownStaticPositioningDemo },
            { path: "fontawesome-toggle", component: dropdown_static_fontawesome_toggle_1.DropdownStaticFontAwesomeToggleDemo },
            { path: "icon-toggle", component: dropdown_static_icon_toggle_1.DropdownStaticIconToggleDemo },
            { path: "textlink-toggle", component: dropdown_static_textlink_toggle_1.DropdownStaticTextLinkToggleDemo },
            { path: "angular-positioning", component: dropdown_angular_positioning_1.DropdownAngularPositioningDemo },
            { path: "multi-click", component: dropdown_angular_close_item_false_1.DropdownAngularCloseItemFalseDemo }
        ]
    }
];
exports.ROUTING = router_1.RouterModule.forChild(ROUTES);

==> clarity-demos-0.7.6.tgz: package/dropdown/demo/dropdown.demo.routing.js <==
"use strict";
var router_1 = require("@angular/router");
var dropdown_demo_1 = require("./dropdown.demo");
var dropdown_static_default_1 = require("./dropdown-static-default");
var dropdown_static_positioning_1 = require("./dropdown-static-positioning");
var dropdown_static_fontawesome_toggle_1 = require("./dropdown-static-fontawesome-toggle");
var dropdown_static_icon_toggle_1 = require("./dropdown-static-icon-toggle");
var dropdown_static_buttonlink_toggle_1 = require("./dropdown-static-buttonlink-toggle");
var dropdown_angular_positioning_1 = require("./dropdown-angular-positioning");
var dropdown_angular_close_item_false_1 = require("./dropdown-angular-close-item-false");
var ROUTES = [
    {
        path: "",
        component: dropdown_demo_1.DropdownDemo,
        children: [
            { path: "", redirectTo: "default", pathMatch: "full" },
            { path: "default", component: dropdown_static_default_1.DropdownStaticDefaultDemo },
            { path: "positioning", component: dropdown_static_positioning_1.DropdownStaticPositioningDemo },
            { path: "fontawesome-toggle", component: dropdown_static_fontawesome_toggle_1.DropdownStaticFontAwesomeToggleDemo },
            { path: "icon-toggle", component: dropdown_static_icon_toggle_1.DropdownStaticIconToggleDemo },
            { path: "buttonlink-toggle", component: dropdown_static_buttonlink_toggle_1.DropdownStaticButtonLinkToggleDemo },
            { path: "angular-positioning", component: dropdown_angular_positioning_1.DropdownAngularPositioningDemo },
            { path: "multi-click", component: dropdown_angular_close_item_false_1.DropdownAngularCloseItemFalseDemo }
        ]
    }
];
exports.ROUTING = router_1.RouterModule.forChild(ROUTES);
